summaryrefslogtreecommitdiff
path: root/django/conf/project_template
diff options
context:
space:
mode:
Diffstat (limited to 'django/conf/project_template')
-rw-r--r--django/conf/project_template/settings.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/django/conf/project_template/settings.py b/django/conf/project_template/settings.py
index 1d33dd13c9..e0265579b8 100644
--- a/django/conf/project_template/settings.py
+++ b/django/conf/project_template/settings.py
@@ -49,16 +49,16 @@ MEDIA_ROOT = ''
# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
+# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = ''
-# Absolute path to the directory that holds media.
+# Absolute path to the directory that holds static files.
# Example: "/home/media/media.lawrence.com/static/"
-STATICFILES_ROOT = ''
+STATIC_ROOT = ''
-# URL that handles the static files served from STATICFILES_ROOT.
-# Example: "http://static.lawrence.com/", "http://example.com/static/"
-STATICFILES_URL = '/static/'
+# URL that handles the static files served from STATIC_ROOT.
+# Example: "http://media.lawrence.com/static/"
+STATIC_URL = '/static/'
# URL prefix for admin media -- CSS, JavaScript and images.
# Make sure to use a trailing slash.